package com.zswl.cloud.springBtach.server.core.controller;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.security.annotations.ResourceAuth;
import com.github.microservice.auth.security.type.AuthType;
import com.zswl.cloud.springBatch.client.model.qiuxiang.OrderRequest;
import com.zswl.cloud.springBatch.client.service.QiuXiangService;
import com.zswl.cloud.springBtach.server.core.api.qiuxiang.QiuXiangApi;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

@Log4j2
@RestController
@RequestMapping("qx")
public class QiuXiangController {

    @Autowired
    QiuXiangApi qiuXiangApi;

    @Autowired
    QiuXiangService qiuXiangService;

    @ApiOperation("下单")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "addOrder", method = RequestMethod.POST)
    public ResultContent placeOrder(@RequestBody OrderRequest orderRequest) {
        return qiuXiangService.placeOrder(orderRequest);
    }

    @ApiOperation("获取订单列表")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "orderList", method = RequestMethod.POST, consumes = {MediaType.APPLICATION_JSON_VALUE})
    public ResultContent orderList(@RequestBody Map<String, String> orderRequest) {

        JSONArray objects = qiuXiangApi.orderList(orderRequest.get("lastOrderId"), orderRequest.get("count"));
        return ResultContent.buildContent(objects);
    }

    @ApiOperation("订单详情")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "orderDelit/{orderId}", method = RequestMethod.GET)
    public ResultContent orderDelit(@PathVariable("orderId") String orderId) {

        return qiuXiangService.orderDelit(orderId);
    }

    @ApiOperation("取消订单")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "cancelOrder", method = RequestMethod.POST, consumes = {MediaType.APPLICATION_JSON_VALUE})
    public ResultContent cancelOrder(@RequestBody Map<String, String> orderRequest) {

        return ResultContent.buildContent(qiuXiangApi.cancelOrder(orderRequest.get("orderId"), orderRequest.get("reason")));
    }

    @ApiOperation("获取司机位置")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "driverLocation", method = RequestMethod.POST, consumes = {MediaType.APPLICATION_JSON_VALUE})
    public ResultContent driverLocation(@RequestBody Map<String, String> orderRequest) {
        return ResultContent.buildContent(qiuXiangApi.driverLocation(orderRequest.get("orderId")));
    }

    @ApiOperation("获取司机行驶轨迹")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "driverLocationLog", method = RequestMethod.POST, consumes = {MediaType.APPLICATION_JSON_VALUE})
    public ResultContent driverLocationLog(@RequestBody Map<String, String> orderRequest) {
        return ResultContent.buildContent(qiuXiangApi.driverLocationLog(orderRequest.get("orderId")));
    }

}
