package com.zswl.cloud.springBtach.server.core.controller;

import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.security.annotations.ResourceAuth;
import com.github.microservice.auth.security.type.AuthType;
import com.zhongshu.payment.client.model.order.v2.CreatOrderResultModel;
import com.zswl.cloud.springBatch.client.model.ypp.movie.request.CreateOrder2Request;
import com.zswl.cloud.springBtach.server.core.api.ypp.KfcApi;
import com.zswl.cloud.springBtach.server.core.service.YppService;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

@Log4j2
@RestController
@RequestMapping("ypp/movie")
public class YppController {

    @Autowired
    private YppService yppService;

    @Autowired
    private KfcApi kfcApi;


    @ApiOperation("创建订单")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "create_order", method = RequestMethod.POST)
    public ResultContent<CreatOrderResultModel> create_order(@RequestBody CreateOrder2Request createOrdereRquest) {
        return yppService.create_order(createOrdereRquest);
    }

    @ApiOperation("热映电影（pageIndex从0开始）")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "movies", method = RequestMethod.GET)
    public ResultContent movies(String cityId, String pageIndex, String pageSize) {
        return yppService.movies(cityId, pageIndex, pageSize);
    }

    @ApiOperation("即将上映电影")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "coming_movies", method = RequestMethod.GET)
    public ResultContent coming_movies(String cityId) {
        return yppService.coming_movies(cityId);
    }

    @ApiOperation("获取电影详情")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "movie_detail", method = RequestMethod.GET)
    public ResultContent movie_detail(String movieId) {
        return yppService.movie_detail(movieId);
    }

    @ApiOperation("获取电影的影院列表")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "movie_cinemas", method = RequestMethod.GET)
    public ResultContent movie_cinemas(String cityId, String movieId, String day, String lat, String lng) {
        return yppService.movie_cinemas(cityId, movieId, day, lat, lng);
    }

    @ApiOperation("获取影院列表")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "cinemas", method = RequestMethod.GET)
    public ResultContent cinemas(String cityId, String districtId, String brandId, String lat, String lng) {
        return yppService.cinemas(cityId, districtId, brandId, lat, lng);
    }

    @ApiOperation("获取影院过滤列表")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "cinema_filter", method = RequestMethod.GET)
    public ResultContent cinema_filter(String cityId) {
        return yppService.cinema_filter(cityId);
    }

    @ApiOperation("获取城市列表")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "get_citys", method = RequestMethod.GET)
    public ResultContent get_citys() {
        return yppService.get_citys();
    }

    @ApiOperation("获取影院某个电影的排片列表")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "cinema_shows", method = RequestMethod.GET)
    public ResultContent cinema_shows(String movieId, String cinemaId) {
        return yppService.cinema_shows(movieId, cinemaId);
    }

    @ApiOperation("获取电影场次（座位）详情")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "session", method = RequestMethod.GET)
    public ResultContent ad_configs(String sessionId, String cinemaId, String movieId, String sid) {
        return yppService.session(sessionId, cinemaId, movieId, sid);
    }

    @ApiOperation("获取广告列表")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "ad_configs", method = RequestMethod.GET)
    public ResultContent ad_configs() {

        return yppService.ad_configs();
    }

    @ApiOperation("点餐聚合页")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "kfcIndex", method = RequestMethod.GET)
    public ResultContent kfcIndex() {

        String index = kfcApi.index();
        return ResultContent.buildContent(index);
    }
}
