package com.zswl.cloud.springBtach.server.core.job.dfy;

import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.client.content.ResultState;
import com.zhongshu.payment.client.model.order.v2.GoodsResultModel;
import com.zhongshu.payment.client.model.order.v2.OrderResult2Model;
import com.zhongshu.payment.client.model.order.v2.UpdateGoodsModel;
import com.zhongshu.payment.client.model.order.v2.VerificationModel;
import com.zhongshu.payment.client.model.payment.SubOrdersConfirmResponseModel;
import com.zhongshu.payment.client.service.v2.OrderService2;
import com.zhongshu.payment.client.service.v2.PaymentService2;
import com.zhongshu.payment.client.type.OrderType;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.request.SubmitOrderRequest;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.response.CreateOrderNewResponse;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.response.SubmitOrderResponse;
import com.zswl.cloud.springBtach.server.core.api.dfy.TicketApi;
import com.zswl.cloud.springBtach.server.core.job.standard.StandarDeliveryJob;
import lombok.Data;
import lombok.experimental.Delegate;
import lombok.extern.log4j.Log4j2;
import org.springframework.batch.core.Job;
import org.springframework.batch.core.Step;
import org.springframework.batch.core.launch.support.RunIdIncrementer;
import org.springframework.batch.repeat.RepeatStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.math.BigDecimal;

@Data
@Log4j2
@Configuration
public class TicketDeliveryJob {

    @Autowired
    @Delegate
    StandarDeliveryJob standarDeliveryJob;


    @Autowired
    OrderService2 orderService2;

    @Autowired
    PaymentService2 paymentService2;

    @Autowired
    TicketApi ticketApi;

    @Value("${dfy.payType}")
    private Integer payType;


    public Step ticketDeliveryStep() {
        return getStepBuilderFactory().get("ticketDeliveryStep")
                .tasklet((contribution, chunkContext) -> {
                    GoodsResultModel goodsResultModel = getParameter().get();
                    ResultContent<OrderResult2Model> goodsResultModelResultContent = orderService2.orderInfo(goodsResultModel.getOrderNo());
                    BigDecimal payAmount = goodsResultModelResultContent.getContent().getPayAmount();

                    String extend = goodsResultModel.getExtend();
                    CreateOrderNewResponse.Datas bean = JSONUtil.toBean(extend, CreateOrderNewResponse.Datas.class);

                    SubmitOrderRequest submitOrderRequest = new SubmitOrderRequest();
                    submitOrderRequest.setPay(payAmount);
                    submitOrderRequest.setPayType(payType);
                    submitOrderRequest.setOrderId(bean.getOrderId());

                    SubmitOrderResponse submitOrderResponse = ticketApi.submitOrderResponse(submitOrderRequest);


                    JSONObject entries1 = JSONUtil.parseObj(extend);
                    entries1.set("response", submitOrderResponse);
                    if (!submitOrderResponse.getSuccess()) {
                        UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();
                        updateGoodsModel.setId(goodsResultModel.getId());
                        updateGoodsModel.setVerifyModel(entries1);
                        orderService2.updateGoods(updateGoodsModel);
                        return RepeatStatus.FINISHED;
                    }

                    // 分账
                    ResultContent<SubOrdersConfirmResponseModel> subOrdersConfirmResponseModelResultContent = paymentService2.subOrdersConfirm(goodsResultModel.getId(), goodsResultModel.getShopId());
                    if (!subOrdersConfirmResponseModelResultContent.getState().equals(ResultState.Success)) {
                        log.info("分账失败：{}", JSONUtil.toJsonStr(goodsResultModel));
                        getResultContent().set(ResultContent.build(ResultState.Fail));
                    }


                    UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();
                    updateGoodsModel.setId(goodsResultModel.getId());
                    updateGoodsModel.setDelivery(true);
                    updateGoodsModel.setGoodsState(OrderType.WAIT_USE);
                    orderService2.updateGoods(updateGoodsModel);

                    getResultContent().set(ResultContent.build(ResultState.Success));
                    return RepeatStatus.FINISHED;

                })
                .build();
    }

    @Bean
    public Job ticketDelivery() {
        return getJobBuilderFactory()
                .get("ticketDelivery")
                .start(ticketDeliveryStep())
                .incrementer(new RunIdIncrementer())
                .build();
    }

}

