package com.zswl.cloud.springBtach.server.core.service.impl;

import cn.hutool.core.lang.Snowflake;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.client.content.ResultState;
import com.github.microservice.auth.security.helper.AuthHelper;
import com.zhongshu.payment.client.model.order.v2.*;
import com.zhongshu.payment.client.service.v2.OrderService2;
import com.zhongshu.payment.client.service.v2.PaymentService2;
import com.zhongshu.payment.client.type.JobFlowMap;
import com.zhongshu.payment.client.type.OrderType;
import com.zhongshu.payment.client.type.TransferOwner;
import com.zhongshu.payment.client.type.TransferType;
import com.zswl.cloud.shop.client.service.ShopService;
import com.zswl.cloud.shop.client.vo.life.AccountDetailVo;
import com.zswl.cloud.shop.client.vo.life.SharePlatformVo;
import com.zswl.cloud.springBatch.client.model.dfy.Hotel.request.*;
import com.zswl.cloud.springBatch.client.model.dfy.Hotel.response.*;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.response.CreateOrderNewResponse;
import com.zswl.cloud.springBatch.client.service.DfyHotelService;
import com.zswl.cloud.springBtach.server.core.api.dfy.DomesticHotelApi;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

@Service
public class DfyHotelServiceImpl implements DfyHotelService {

    @Autowired
    private DomesticHotelApi domesticHotelApi;

    @Autowired
    private Snowflake snowflake;

    @Autowired
    private OrderService2 orderService2;

    @Autowired
    private AuthHelper authHelper;

    @Autowired
    private ShopService shopService;

    @Autowired
    private PaymentService2 paymentService2;


    public ResultContent<QueryNewResponse> queryNew(QueryNewRequest queryNewRequest) {
        QueryNewResponse queryNewResponse = domesticHotelApi.queryNew(queryNewRequest);
        if (queryNewResponse.getSuccess()) {
            return ResultContent.buildContent(queryNewResponse);
        }
        return ResultContent.build(ResultState.Fail, queryNewResponse.getMsg());
    }

    public ResultContent<HotelListResponse> hotelList(HotelListRequest hotelListRequest) {
        HotelListResponse hotelListResponse = domesticHotelApi.hotelList(hotelListRequest);
        if (hotelListResponse.getSuccess()) {

            return ResultContent.buildContent(hotelListResponse);
        }
        return ResultContent.build(ResultState.Fail, hotelListResponse.getMsg());
    }

    public ResultContent<HotelDetailResponse> hotelDetail(HotelDetailRequest hotelDetailRequest) {
        HotelDetailResponse hotelDetailResponse = domesticHotelApi.hotelDetail(hotelDetailRequest);
        if (hotelDetailResponse.getSuccess()) {
            return ResultContent.buildContent(hotelDetailResponse);
        }
        return ResultContent.build(ResultState.Fail, hotelDetailResponse.getMsg());
    }

    public ResultContent<RatePlanInfoResponse> ratePlanInfo(RatePlanInfoRequest ratePlanInfoRequest) {
        RatePlanInfoResponse ratePlanInfoResponse = domesticHotelApi.ratePlanInfo(ratePlanInfoRequest);
        if (ratePlanInfoResponse.getSuccess()) {
            return ResultContent.buildContent(ratePlanInfoResponse);
        }
        return ResultContent.build(ResultState.Fail, ratePlanInfoResponse.getMsg());
    }

    public ResultContent<RatePlanResponse> ratePlan(RatePlanRequest ratePlanRequest) {
        RatePlanResponse ratePlanResponse = domesticHotelApi.ratePlan(ratePlanRequest);
        if (ratePlanResponse.getSuccess()) {

            return ResultContent.buildContent(ratePlanResponse);
        }
        return ResultContent.build(ResultState.Fail, ratePlanResponse.getMsg());
    }

    public ResultContent<CreatOrderResultModel> addOrder(AddOrderRequest addOrderRequest) {

        com.zswl.cloud.shop.client.ret.ResultContent<AccountDetailVo> shopSetting = shopService.shopSetting("酒店");
        if (!shopSetting.getState().equals(com.zswl.cloud.shop.client.ret.ResultState.Success)) {
            return ResultContent.build(ResultState.Fail, "酒店商户信息未配置");
        }
        AccountDetailVo accountDetailVo = shopSetting.getContent();


        String orderNo = snowflake.nextIdStr();
        addOrderRequest.setSourceOrderId(orderNo);
        HotelDetailRequest hotelDetailRequest = new HotelDetailRequest();
        hotelDetailRequest.setHotelId(addOrderRequest.getHotelId());
        HotelDetailResponse hotelDetailResponse = domesticHotelApi.hotelDetail(hotelDetailRequest);

        RatePlanRequest ratePlanRequest = new RatePlanRequest();
        ratePlanRequest.setRoomId(addOrderRequest.getRatePlanId());
        ratePlanRequest.setHotelId(addOrderRequest.getHotelId());
        ratePlanRequest.setCheckin(addOrderRequest.getCheckin());
        ratePlanRequest.setCheckout(addOrderRequest.getCheckout());
        ratePlanRequest.setRoomNum(addOrderRequest.getNumberofRooms());
        ratePlanRequest.setChildNum(addOrderRequest.getChildNum());
        ratePlanRequest.setChildAges(addOrderRequest.getChildAges());

        RatePlanResponse ratePlanResponse = domesticHotelApi.ratePlan(ratePlanRequest);
        if (!ratePlanResponse.getSuccess()) {
            return ResultContent.build(ResultState.Fail, ratePlanResponse.getMsg());
        }
        BigDecimal totalPrice = ratePlanResponse.getData().getTotalPrice();
        addOrderRequest.setTotalPrice(totalPrice.intValue());


        AddOrderResponse addOrderResponse = domesticHotelApi.addOrder(addOrderRequest);
        if (!addOrderResponse.getSuccess()) {
            return ResultContent.build(ResultState.Fail, addOrderResponse.getMsg());
        }
// 平台订单
        OrderDetailRequest orderDetailRequest = new OrderDetailRequest();
        orderDetailRequest.setOrderId(addOrderResponse.getData().getOrderId());
        OrderDetailResponse orderDetailResponse = domesticHotelApi.orderDetail(orderDetailRequest);

        String shopId = accountDetailVo.getAccountId();
        String authAccount = accountDetailVo.getAuthAccount();
        SharePlatformVo sharePlatformVo = accountDetailVo.getSharePlatformVo();

        // 平台订单
        CreateOrder2Model createOrder2Model = new CreateOrder2Model();
        createOrder2Model.setOrderNo(orderNo);
        createOrder2Model.setUserId(authHelper.getCurrentUser().getUserId());
        createOrder2Model.setShopId(shopId);
        JSONObject shopInfo = JSONUtil.parseObj(hotelDetailResponse.getData());
        shopInfo.set("hotelIdPic", addOrderRequest.getHotelIdPic());
        shopInfo.set("shopName", hotelDetailResponse.getData().getChineseName());
        createOrder2Model.setShopInfo(shopInfo);
        createOrder2Model.setTotalAmount(totalPrice);
        createOrder2Model.setDiscountAmount(BigDecimal.ZERO);
        createOrder2Model.setPayAmount(totalPrice);
        createOrder2Model.setAccesserUserId(authAccount);
        createOrder2Model.setChannel(addOrderRequest.getChannel());
        JSONObject goodsInfo = JSONUtil.parseObj(addOrderRequest);
        goodsInfo.set("hotelInfo", orderDetailResponse.getData().getHotelInfo());
        goodsInfo.set("channelOrderId", String.valueOf(addOrderResponse.getData().getOrderId()));
        goodsInfo.set("goodsName", addOrderRequest.getRoomNameCn());
        goodsInfo.set("goodsPath", addOrderRequest.getRoomPic());
        goodsInfo.set("ratePlan", ratePlanResponse);

        CreateOrder2Model.Goods goods = new CreateOrder2Model.Goods();
        goods.setGoodsId(addOrderRequest.getRatePlanId());
        goods.setJobFlowMap(JobFlowMap.Hotel);
        goods.setGoodsInfo(goodsInfo);
        goods.setPayAmount(totalPrice);
        goods.setValidDay(90);
        goods.setTransferType(sharePlatformVo.getShareType().equals(1) ? TransferType.RATIO : TransferType.FIXED);

        List<CreateOrder2Model.Owner> ownerList = new ArrayList<>();

        CreateOrder2Model.Owner platfor = new CreateOrder2Model.Owner();
        platfor.setOwner(TransferOwner.PLATFORM);
        platfor.setValue(sharePlatformVo.getPlatformRate());

        CreateOrder2Model.Owner buy = new CreateOrder2Model.Owner();
        buy.setOwner(TransferOwner.BUY_SHOP);
        buy.setValue(sharePlatformVo.getBuyShopRate());
        buy.setShopId(shopId);

        CreateOrder2Model.Owner use = new CreateOrder2Model.Owner();
        use.setOwner(TransferOwner.USE_SHOP);
        use.setValue(sharePlatformVo.getCheckShopRate());

        ownerList.add(platfor);
        ownerList.add(buy);
        ownerList.add(use);
        goods.setTransferRrule(ownerList);
        JSONObject entries = JSONUtil.parseObj(addOrderResponse.getData());
        entries.put("orderInfo", orderDetailResponse.getData().getOrderInfo());
        goods.setExtend(JSONUtil.toJsonStr(entries));
        createOrder2Model.setGoodsList(List.of(goods));
        return orderService2.creat(createOrder2Model);

    }

    public ResultContent<OrderDetailResponse> orderDetail(OrderDetailRequest orderDetailRequest) {
        ResultContent<GoodsResultModel> goodsResultModelResultContent =  orderService2.findChannelGoods(JobFlowMap.Hotel,String.valueOf(orderDetailRequest.getOrderId()));
        GoodsResultModel goodsResultModel = goodsResultModelResultContent.getContent();
        OrderDetailResponse orderDetailResponse = domesticHotelApi.orderDetail(orderDetailRequest);
        if (orderDetailResponse.getSuccess()) {
            String orderStatus = orderDetailResponse.getData().getOrderInfo().getOrderStatus();
            String extend = goodsResultModel.getExtend();
            JSONObject entries = JSONUtil.parseObj(extend);
            entries.put("orderInfo", orderDetailResponse.getData().getOrderInfo());
            UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();
            updateGoodsModel.setId(goodsResultModel.getId());
            updateGoodsModel.setExtend(JSONUtil.toJsonStr(entries));
            switch (orderStatus) {
                case "已取消":
                    switch (goodsResultModel.getGoodsState()) {
                        case WAIT_PAYMENT:
                            UpdateOrder2Model updateOrder2Model = new UpdateOrder2Model();
                            updateOrder2Model.setOrderType(OrderType.CLOSE);
                            updateOrder2Model.setOrderNo(goodsResultModel.getOrderNo());
                            orderService2.updateOrderType(updateOrder2Model);
                            break;
                        case WAIT_USE:
                            ApplicantRefundParam2Model applicantRefundParam2Model = new ApplicantRefundParam2Model();
                            applicantRefundParam2Model.setUserId(goodsResultModel.getUserId());
                            applicantRefundParam2Model.setId(goodsResultModel.getId());
                            applicantRefundParam2Model.setRemark("渠道服通知取消");
                            paymentService2.refund(applicantRefundParam2Model);
                            break;
                    }
                    break;
                case "已完成":
                    updateGoodsModel.setGoodsState(OrderType.USED);
                    updateGoodsModel.setId(goodsResultModel.getId());
                    break;
            }
            orderService2.updateGoods(updateGoodsModel);
            return ResultContent.build(ResultState.Success, orderDetailResponse);
        }


        return ResultContent.build(ResultState.Fail, orderDetailResponse.getMsg());
    }

    public ResultContent<SubmitOrderResponse> submitOrder(SubmitOrderRequest submitOrderRequest) {
        return ResultContent.buildContent(domesticHotelApi.submitOrder(submitOrderRequest));
    }

    public ResultContent<CancelOrderResponse> cancelOrder(CancelOrderRequest cancelOrderRequest) {


        ResultContent<List<GoodsResultModel>> listResultContent = orderService2.goodsDetail(cancelOrderRequest.getOrderId());
        GoodsResultModel goodsResultModel = listResultContent.getContent().get(0);
        String extend = goodsResultModel.getExtend();
        CreateOrderNewResponse.Datas bean = JSONUtil.toBean(extend, CreateOrderNewResponse.Datas.class);
        cancelOrderRequest.setOrderId(String.valueOf(bean.getOrderId()));
        CancelOrderResponse cancelOrderResponse = domesticHotelApi.cancelOrder(cancelOrderRequest);
        if (cancelOrderResponse.getSuccess()) {
            switch (goodsResultModel.getGoodsState()) {
                case WAIT_USE:
                    ApplicantRefundParam2Model applicantRefundParam2Model = new ApplicantRefundParam2Model();
                    applicantRefundParam2Model.setUserId(goodsResultModel.getUserId());
                    applicantRefundParam2Model.setId(goodsResultModel.getId());
                    applicantRefundParam2Model.setRemark(cancelOrderRequest.getRemark());
                    paymentService2.applicantRefund(applicantRefundParam2Model);
                    break;
                case WAIT_PAYMENT:
                    paymentService2.close(cancelOrderRequest.getOrderId(), authHelper.getCurrentUser().getUserId());
                    break;
            }

        }
        OrderDetailRequest orderDetailRequest = new OrderDetailRequest();
        orderDetailRequest.setOrderId(bean.getOrderId());
        OrderDetailResponse orderDetailResponse = domesticHotelApi.orderDetail(orderDetailRequest);
        JSONObject entries = JSONUtil.parseObj(extend);
        entries.put("orderInfo", orderDetailResponse.getData().getOrderInfo());
        UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();
        updateGoodsModel.setId(goodsResultModel.getId());
        updateGoodsModel.setExtend(JSONUtil.toJsonStr(entries));
        orderService2.updateGoods(updateGoodsModel);

        return cancelOrderResponse.getSuccess()?ResultContent.buildContent(cancelOrderResponse.getData().getMsg()):ResultContent.build(ResultState.Fail, cancelOrderResponse.getMsg());

    }
}
