package com.zswl.cloud.springBtach.server.core.service.impl;

import cn.hutool.core.lang.Snowflake;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.client.content.ResultState;
import com.github.microservice.auth.security.helper.AuthHelper;
import com.zhongshu.payment.client.model.order.v2.*;
import com.zhongshu.payment.client.service.v2.OrderService2;
import com.zhongshu.payment.client.service.v2.PaymentService2;
import com.zhongshu.payment.client.type.JobFlowMap;
import com.zhongshu.payment.client.type.OrderType;
import com.zhongshu.payment.client.type.TransferOwner;
import com.zhongshu.payment.client.type.TransferType;
import com.zswl.cloud.shop.client.dto.life.TripartiteShopDto;
import com.zswl.cloud.shop.client.service.ShopService;
import com.zswl.cloud.shop.client.vo.life.ShopDetailVo;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.request.*;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.response.*;
import com.zswl.cloud.springBatch.client.service.DfyTicketService;
import com.zswl.cloud.springBtach.server.core.api.dfy.TicketApi;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

@Service
@Log4j2
public class DfyTicketServiceImpl implements DfyTicketService {

    @Autowired
    TicketApi ticketApi;

    @Autowired
    ShopService shopService;
    @Autowired
    private AuthHelper authHelper;

    @Autowired
    private Snowflake snowflake;

    @Autowired
    private OrderService2 orderService2;

    @Autowired
    private PaymentService2 paymentService2;

    public ResultContent<ScenicListResponse> scenicList(ScenicListRequest scenicListRequest) {
        ScenicListResponse scenicListResponse = ticketApi.scenicList(scenicListRequest);
        if (scenicListResponse.getSuccess()) {
            return ResultContent.buildContent(scenicListResponse);
        }
        return ResultContent.build(ResultState.Fail, scenicListResponse.getMsg());
    }


    public ResultContent<ScenicDetailResponse> scenicDetail(ScenicDetailRequest scenicDetailRequest) {
        ScenicDetailResponse scenicDetailResponse = ticketApi.scenicDetail(scenicDetailRequest);
        if (scenicDetailResponse.getSuccess()) {
            return ResultContent.buildContent(scenicDetailResponse);
        }
        return ResultContent.build(ResultState.Fail, scenicDetailResponse.getMsg());
    }


    public ResultContent<PrivilegeTicketListResponse> privilegeTicketList(PrivilegeTicketListRequest privilegeTicketListRequest) {

        PrivilegeTicketListResponse privilegeTicketListResponse = ticketApi.privilegeTicketList(privilegeTicketListRequest);
        if (privilegeTicketListResponse.getSuccess()) {
            return ResultContent.buildContent(privilegeTicketListResponse);
        }
        return ResultContent.build(ResultState.Fail, privilegeTicketListResponse.getMsg());
    }


    public ResultContent<DetailResponse> detail(DetailRequest detailRequest) {
        DetailResponse detail = ticketApi.detail(detailRequest);
        if (detail.getSuccess()) {
            return ResultContent.buildContent(detail);
        }
        return ResultContent.build(ResultState.Fail, detail.getMsg());
    }


    public ResultContent<CreatOrderResultModel> createOrderNew(CreateOrderNewRequest createOrderNewRequest) {

        String orderNo = snowflake.nextIdStr();
        createOrderNewRequest.setSourceOrderId(orderNo);

        DetailResponse detailResponse = ticketApi.detail(new DetailRequest(createOrderNewRequest.getProductId()));
        ScenicDetailResponse scenicDetailResponse = ticketApi.scenicDetail(new ScenicDetailRequest(createOrderNewRequest.getScenicId()));
        List<DetailResponse.PriceCalendar> priceCalendar = detailResponse.getData().getPriceCalendar();
        List<DetailResponse.PriceCalendar> collect = priceCalendar.stream().filter(it -> it.getDepartDate().equals(createOrderNewRequest.getStartTime())).collect(Collectors.toList());
        if (collect.isEmpty()) {
            return ResultContent.build(ResultState.Fail, "未找到对应的价格日历！");
        }
        BigDecimal salePrice = collect.get(0).getSalePrice();
        BigDecimal payAmount = salePrice.multiply(BigDecimal.valueOf(createOrderNewRequest.getBookNumber()));

        ShopDetailVo shopDetailVo = shopService.detail(createOrderNewRequest.getEpId()).getContent();
        String authAccount = shopDetailVo.getAuthAccount();
        if (ObjectUtil.isEmpty(authAccount)) {
            return ResultContent.build(ResultState.Fail, "分账账户未设置");
        }
        CreateOrderNewRequest2 createOrderNewRequest2 = new CreateOrderNewRequest2();
        BeanUtils.copyProperties(createOrderNewRequest, createOrderNewRequest2);

        // 渠道订单
        CreateOrderNewResponse createOrderNewResponse = ticketApi.createOrderNew(createOrderNewRequest2);

        if (!createOrderNewResponse.getSuccess()) {
            return ResultContent.build(ResultState.Fail, createOrderNewResponse.getMsg());
        }

        OrderDetailRequest orderDetailRequest = new OrderDetailRequest();
        orderDetailRequest.setOrderId(createOrderNewResponse.getData().getOrderId());
        OrderDetailResponse orderDetailResponse = ticketApi.orderDetail(orderDetailRequest);

        // 平台订单
        CreateOrder2Model createOrder2Model = new CreateOrder2Model();
        createOrder2Model.setOrderNo(orderNo);
        createOrder2Model.setUserId(authHelper.getCurrentUser().getUserId());
        createOrder2Model.setShopId(createOrderNewRequest.getEpId());
        createOrder2Model.setShopInfo(JSONUtil.parseObj(shopDetailVo));
        createOrder2Model.setTotalAmount(payAmount);
        createOrder2Model.setDiscountAmount(BigDecimal.ZERO);
        createOrder2Model.setPayAmount(payAmount);
        createOrder2Model.setAccesserUserId(authAccount);
        createOrder2Model.setChannel(createOrderNewRequest.getChannel());
        JSONObject goodsInfo = JSONUtil.parseObj(createOrderNewRequest2);
        goodsInfo.set("channelOrderId", String.valueOf(createOrderNewResponse.getData().getOrderId()));
        goodsInfo.set("goodsName", detailResponse.getData().getProductName());
        goodsInfo.set("goodsPath", scenicDetailResponse.getData().getDefaultPic());
        goodsInfo.set("scenicId", createOrderNewRequest.getScenicId());
        goodsInfo.set("salePrice", salePrice);


        CreateOrder2Model.Goods goods = new CreateOrder2Model.Goods();
        goods.setGoodsId(String.valueOf(createOrderNewRequest.getProductId()));
        goods.setJobFlowMap(JobFlowMap.Ticket);
        goods.setGoodsInfo(goodsInfo);
        goods.setPayAmount(payAmount);
        goods.setValidDay(30);
        goods.setTransferType(shopDetailVo.getShareType().equals(1) ? TransferType.RATIO : TransferType.FIXED);

        List<CreateOrder2Model.Owner> ownerList = new ArrayList<>();

        CreateOrder2Model.Owner platfor = new CreateOrder2Model.Owner();
        platfor.setOwner(TransferOwner.PLATFORM);
        platfor.setValue(shopDetailVo.getPlatformRate());

        CreateOrder2Model.Owner buy = new CreateOrder2Model.Owner();
        buy.setOwner(TransferOwner.BUY_SHOP);
        buy.setValue(shopDetailVo.getBuyShopRate());
        buy.setShopId(createOrderNewRequest.getEpId());

        ownerList.add(platfor);
        ownerList.add(buy);
        goods.setTransferRrule(ownerList);
        JSONObject entries = JSONUtil.parseObj(createOrderNewResponse.getData());
        entries.put("orderInfo", orderDetailResponse.getData().getOrderInfo());
        goods.setExtend(JSONUtil.toJsonStr(entries));
        createOrder2Model.setGoodsList(List.of(goods));
        return orderService2.creat(createOrder2Model);
    }


    public ResultContent cancelOrder(CancelOrderRequest cancelOrderRequest) {
        ResultContent close = paymentService2.close(cancelOrderRequest.getOrderId(), authHelper.getCurrentUser().getUserId());
        if (close.getState().equals(ResultState.Success)) {
            ResultContent<List<GoodsResultModel>> listResultContent = orderService2.goodsDetail(cancelOrderRequest.getOrderId());
            GoodsResultModel goodsResultModel = listResultContent.getContent().get(0);
            String extend = goodsResultModel.getExtend();
            CreateOrderNewResponse.Datas bean = JSONUtil.toBean(extend, CreateOrderNewResponse.Datas.class);
            Object o = goodsResultModel.getGoodsInfo().get(bean.getOrderId());
            cancelOrderRequest.setOrderId(String.valueOf(o));
            ticketApi.cancelOrder(cancelOrderRequest);
        }


        return close;
    }


    public ResultContent<SubmitOrderResponse> submitOrderResponse(SubmitOrderRequest submitOrderRequest) {
        return ResultContent.buildContent(ticketApi.submitOrderResponse(submitOrderRequest));

    }


    public ResultContent<OrderDetailResponse> orderDetail(OrderDetailRequest orderDetailRequest) {
        ResultContent<GoodsResultModel> goodsResultModelResultContent = orderService2.findChannelGoods(JobFlowMap.Ticket, String.valueOf(orderDetailRequest.getOrderId()));
        GoodsResultModel goodsResultModel = goodsResultModelResultContent.getContent();
        OrderDetailResponse orderDetailResponse = ticketApi.orderDetail(orderDetailRequest);
        if (orderDetailResponse.getSuccess()) {
            String orderStatus = orderDetailResponse.getData().getOrderStatus();

            String extend = goodsResultModel.getExtend();
            JSONObject entries = JSONUtil.parseObj(extend);
            entries.put("orderInfo", orderDetailResponse.getData());
            UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();
            updateGoodsModel.setId(goodsResultModel.getId());
            updateGoodsModel.setExtend(JSONUtil.toJsonStr(entries));
            switch (orderStatus) {
                case "已取消":
                    switch (goodsResultModel.getGoodsState()) {
                        case WAIT_PAYMENT:
                            UpdateOrder2Model updateOrder2Model = new UpdateOrder2Model();
                            updateOrder2Model.setOrderType(OrderType.CLOSE);
                            updateOrder2Model.setOrderNo(goodsResultModel.getOrderNo());
                            orderService2.updateOrderType(updateOrder2Model);
                            break;
                        case WAIT_USE:
                            ApplicantRefundParam2Model applicantRefundParam2Model = new ApplicantRefundParam2Model();
                            applicantRefundParam2Model.setUserId(goodsResultModel.getUserId());
                            applicantRefundParam2Model.setId(goodsResultModel.getId());
                            applicantRefundParam2Model.setRemark("渠道服通知取消");
                            paymentService2.refund(applicantRefundParam2Model);
                            break;
                    }
                    return ResultContent.buildContent(orderDetailResponse);
                case "已完成":
                    updateGoodsModel.setGoodsState(OrderType.USED);
                    break;
            }
            orderService2.updateGoods(updateGoodsModel);
            return ResultContent.buildContent(orderDetailResponse);
        }
        return ResultContent.build(ResultState.Fail, orderDetailResponse.getMsg());
    }


    public ResultContent<OrderStatusResponse> orderStatus(OrderStatusRequest orderStatusRequest) {

        OrderStatusResponse orderStatusResponse = ticketApi.orderStatus(orderStatusRequest);
        if (orderStatusResponse.getSuccess()) {

            return ResultContent.buildContent(orderStatusResponse);
        }
        return ResultContent.build(ResultState.Fail, orderStatusResponse.getMsg());
    }


    public ResultContent<VerifyOrderResponse> verifyOrder(VerifyOrderRequest verifyOrderRequest) {
        return ResultContent.buildContent(ticketApi.verifyOrder(verifyOrderRequest));

    }


    public ResultContent<TuiPiaoResponse> tuiPiao(TuiPiaoRequest tuiPiaoRequest) {
        ResultContent<List<GoodsResultModel>> listResultContent = orderService2.goodsDetail(tuiPiaoRequest.getOrderId());
        GoodsResultModel goodsResultModel = listResultContent.getContent().get(0);
        String extend = goodsResultModel.getExtend();
        CreateOrderNewResponse.Datas bean = JSONUtil.toBean(extend, CreateOrderNewResponse.Datas.class);
        Integer orderId = bean.getOrderId();
        tuiPiaoRequest.setOrderId(String.valueOf(orderId));
        TuiPiaoResponse tuiPiaoResponse = ticketApi.tuiPiao(tuiPiaoRequest);
        if (tuiPiaoResponse.getSuccess()) {
            ApplicantRefundParam2Model applicantRefundParam2Model = new ApplicantRefundParam2Model();
            applicantRefundParam2Model.setUserId(authHelper.getCurrentUser().getUserId());
            applicantRefundParam2Model.setId(goodsResultModel.getId());
            applicantRefundParam2Model.setRemark(tuiPiaoRequest.getCauseContent());
            paymentService2.applicantRefund(applicantRefundParam2Model);
        }

        return tuiPiaoResponse.getSuccess() ? ResultContent.buildContent(tuiPiaoResponse) : ResultContent.build(ResultState.Fail, tuiPiaoResponse.getMsg());

    }


    public void sync() {


        int pageNo = 1;
        int pageSize = 10;

        try {

            while (true) {
                ScenicListRequest scenicListRequest = new ScenicListRequest();
                scenicListRequest.setPage(pageNo);
                scenicListRequest.setPageSize(pageSize);

                ScenicListResponse scenicListResponse = ticketApi.scenicList(scenicListRequest);
                if (scenicListResponse.getData().getRows().size() == 0) {
                    return;
                }
                for (ScenicListResponse.rows row : scenicListResponse.getData().getRows()) {
                    ScenicDetailResponse scenicDetailResponse = ticketApi.scenicDetail(new ScenicDetailRequest(row.getScenicId()));
                    ScenicDetailResponse.Datas data = scenicDetailResponse.getData();

                    String glocation = row.getGlocation();
                    if (ObjectUtil.isEmpty(glocation)) {
                        break;
                    }
                    String[] split = glocation.split(",");

                    TripartiteShopDto tripartiteShopDto = new TripartiteShopDto();
                    tripartiteShopDto.setKey("门票");
                    tripartiteShopDto.setTripartiteId(row.getScenicId());
                    tripartiteShopDto.setShopName(row.getScenicName());
                    tripartiteShopDto.setShopMenuId("1");
                    tripartiteShopDto.setProvince(ObjectUtil.isEmpty(data.getProvinceName()) ? data.getCityName() : data.getProvinceName());
                    tripartiteShopDto.setCity(data.getCityName());
                    tripartiteShopDto.setAddress(row.getAddress());
                    tripartiteShopDto.setMapLon(split[1]);
                    tripartiteShopDto.setMapLat(split[0]);
                    tripartiteShopDto.setLogoPath(row.getNewPicUrl());
                    tripartiteShopDto.setDetailImg(data.getDefaultPic());
                    tripartiteShopDto.setTripartiteJson(JSONUtil.toJsonStr(data));

                    com.zswl.cloud.shop.client.ret.ResultContent resultContent = shopService.tripartiteShop(tripartiteShopDto);
                    log.info("景区创建店铺响应：{}", JSONUtil.toJsonStr(resultContent));


                }
                pageNo++;
            }

        } catch (Exception e) {
            log.error("pageNo：{}；pageSize：{}", pageNo, pageSize);
            e.printStackTrace();
        }


    }
}
