package com.zswl.cloud.springBtach.server.core.service.impl;


import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.lang.Snowflake;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.client.content.ResultState;
import com.github.microservice.auth.security.helper.AuthHelper;
import com.github.microservice.auth.security.model.AuthDetails;
import com.xiaoju.open.oil.commons.OilRequest;
import com.xiaoju.open.oil.commons.config.OilConfig;
import com.xiaoju.open.oil.core.QueryClient;
import com.xiaoju.open.oil.core.QueryClientFactory;
import com.xiaoju.open.oil.core.executor.ResponseDTO;
import com.xiaoju.open.oil.interfaces.domain.*;
import com.xiaoju.open.oil.interfaces.request.*;
import com.zhongshu.vip.client.model.VipUserModel;
import com.zhongshu.vip.client.service.VipUserService;
import com.zswl.cloud.springBatch.client.model.xiaoju.ActivityModel;
import com.zswl.cloud.springBatch.client.model.xiaoju.QueryApiStorePriceRequest;
import com.xiaoju.open.oil.interfaces.request.miniprogram.MiniCancelOrderStatusRequest;
import com.xiaoju.open.oil.interfaces.response.*;
import com.xiaoju.open.oil.security.secret.SecurityService;
import com.zhongshu.payment.client.model.order.v2.*;
import com.zhongshu.payment.client.service.v2.OrderService2;
import com.zhongshu.payment.client.type.JobFlowMap;
import com.zhongshu.payment.client.type.OrderType;
import com.zhongshu.payment.client.type.TransferOwner;
import com.zhongshu.payment.client.type.TransferType;
import com.zswl.cloud.shop.client.dto.life.TripartiteShopDto;
import com.zswl.cloud.shop.client.service.ShopService;
import com.zswl.cloud.springBatch.client.model.request.*;
import com.zswl.cloud.springBatch.client.service.XiaoJuService;
import com.zswl.cloud.springBtach.server.core.dao.*;
import com.zswl.cloud.springBtach.server.core.domain.*;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.*;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.stream.Collectors;

@Log4j2
@Service
public class XiaoJuServiceImpl implements XiaoJuService {


    @Autowired
    AuthHelper authHelper;

    @Autowired
    XiaoJuStoreDao xiaoJuStoreDao;

    @Autowired
    OilConfig oilConfig;

    @Autowired
    XiaoJuOrderDao xiaoJuOrderDao;

    @Autowired
    Snowflake snowflake;

    @Autowired
    ApiLogDao apiLogDao;

    @Autowired
    XiaoJuActivityDao xiaoJuActivityDao;

    @Autowired
    private ShopService shopService;

    @Autowired
    private OrderService2 orderService2;

    @Autowired
    private VipUserService vipUserService;
    @Autowired
    private XiaoJuActivityReceiverDao xiaoJuActivityReceiverDao;

    // 同步加油站
    public ResponseDTO notificationPushStoreInfoRequest(OilRequest oilRequest) {

        TripartiteShopDto tripartiteShopDto = new TripartiteShopDto();

        log.info("原始请求notificationPushStoreInfoRequest：{}", JSONUtil.toJsonStr(oilRequest));
        String s = SecurityService.genDecodeData(oilRequest.getData(), oilConfig.getDataSecret(), oilConfig.getDataSecretIV());

        ApiLog apiLog = new ApiLog();
        apiLog.setService("notificationPushStoreInfoRequest");
        apiLog.setRequest(s);
        apiLog.setSystem("xiaoju");


        XiaoJuStore xiaoJuStore = JSONUtil.toBean(s, XiaoJuStore.class);
        tripartiteShopDto.setKey("加油");
        tripartiteShopDto.setTripartiteId(xiaoJuStore.getStoreId());
        tripartiteShopDto.setShopName(xiaoJuStore.getStoreName());
        tripartiteShopDto.setShopMenuId("4");
        tripartiteShopDto.setProvince(xiaoJuStore.getProvinceName());
        tripartiteShopDto.setCity(xiaoJuStore.getCityName());
        tripartiteShopDto.setAddress(xiaoJuStore.getAddress());
        tripartiteShopDto.setMapLon(String.valueOf(xiaoJuStore.getLon()));
        tripartiteShopDto.setMapLat(String.valueOf(xiaoJuStore.getLat()));
        tripartiteShopDto.setLogoPath(xiaoJuStore.getLogo());
        if (xiaoJuStore.getPicList().size() > 0) {
            tripartiteShopDto.setDetailImg(xiaoJuStore.getPicList().get(0));
        }
        tripartiteShopDto.setTripartiteJson(JSONUtil.toJsonStr(s));

        com.zswl.cloud.shop.client.ret.ResultContent resultContent = shopService.tripartiteShop(tripartiteShopDto);
        log.info("创建店铺响应{}", JSONUtil.toJsonStr(resultContent));


        XiaoJuStore byStoreId = xiaoJuStoreDao.findByStoreId(xiaoJuStore.getStoreId());
        if (byStoreId != null) {
            BeanUtils.copyProperties(byStoreId, xiaoJuStore, "id", "updateTime");
            byStoreId.setLocation(new double[]{xiaoJuStore.getLon(), xiaoJuStore.getLat()});
            xiaoJuStoreDao.save(byStoreId);
        } else {
            xiaoJuStore.setLocation(new double[]{xiaoJuStore.getLon(), xiaoJuStore.getLat()});
            xiaoJuStoreDao.save(xiaoJuStore);
        }

        String data = SecurityService.genEncodeData("{\"success\":true,\"msg\":\"ok\"}", oilConfig.getDataSecret(), oilConfig.getDataSecretIV());
        String sig = SecurityService.genSigData(data, oilConfig.getDataSecret());
        ResponseDTO responseDTO = new ResponseDTO();
        responseDTO.setAppKey(oilConfig.getAppId());
        responseDTO.setCode("0");
        responseDTO.setMsg("请求成功");
        responseDTO.setData(data);
        responseDTO.setSig(sig);
        apiLog.setResponse(JSONUtil.toJsonStr(responseDTO));
        apiLogDao.save(apiLog);
        return responseDTO;

    }

    public ResponseDTO notifyOrderInfo(OilRequest oilRequest) {

        log.info("原始请求notifyOrderInfo：{}", JSONUtil.toJsonStr(oilRequest));
        String s = SecurityService.genDecodeData(oilRequest.getData(), oilConfig.getDataSecret(), oilConfig.getDataSecretIV());

        ApiLog apiLog = new ApiLog();
        apiLog.setService("notifyOrderInfo");
        apiLog.setRequest(s);
        apiLog.setSystem("xiaoju");

        log.info("通知 订单状态：{}", s);
        NotificationOrderInfoRequest notificationOrderInfoRequest = JSONUtil.toBean(s, NotificationOrderInfoRequest.class);

        XiaoJuOrder byOutOrderId = xiaoJuOrderDao.findByOutOrderId(notificationOrderInfoRequest.getOutOrderId());
        BeanUtils.copyProperties(notificationOrderInfoRequest, byOutOrderId);
        xiaoJuOrderDao.save(byOutOrderId);


        ResultContent<List<GoodsResultModel>> listResultContent = orderService2.goodsDetail(notificationOrderInfoRequest.getOutOrderId());
        for (GoodsResultModel goodsResultModel : listResultContent.getContent()) {
            JSONObject entries = JSONUtil.parseObj(goodsResultModel.getExtend());

            UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();

            UpdateOrder2Model updateOrder2Model = new UpdateOrder2Model();
            updateOrder2Model.setOrderNo(goodsResultModel.getOrderNo());
            updateGoodsModel.setId(goodsResultModel.getId());
            Integer orderStatus = notificationOrderInfoRequest.getOrderStatus();
            switch (orderStatus) {
                case 1:
                    entries.set("waitPayment", notificationOrderInfoRequest);
                    updateGoodsModel.setGoodsState(OrderType.WAIT_PAYMENT);
                    break;
                case 2:
                    entries.set("notifyOrderInfo", notificationOrderInfoRequest);
                    updateGoodsModel.setGoodsState(OrderType.USED);
                    updateOrder2Model.setOrderType(OrderType.HAVE_PAID);
                    break;
                case 6:
                    entries.set("refund", notificationOrderInfoRequest);
                    updateGoodsModel.setGoodsState(OrderType.REFUNDED);
                    break;
                case 9:
                    entries.set("close", notificationOrderInfoRequest);
                    updateGoodsModel.setGoodsState(OrderType.CLOSE);
                    updateOrder2Model.setOrderType(OrderType.CLOSE);
                    break;
            }
            updateGoodsModel.setExtend(JSONUtil.toJsonStr(entries));
            orderService2.updateGoods(updateGoodsModel);
            orderService2.updateOrderType(updateOrder2Model);


        }


        String data = SecurityService.genEncodeData("{\"state\":true,\"message\":\"成功\"}", oilConfig.getDataSecret(), oilConfig.getDataSecretIV());
        String sig = SecurityService.genSigData(data, oilConfig.getDataSecret());
        ResponseDTO responseDTO = new ResponseDTO();
        responseDTO.setAppKey(oilConfig.getAppId());
        responseDTO.setCode("0");
        responseDTO.setMsg("请求成功");
        responseDTO.setData(data);
        responseDTO.setSig(sig);
        apiLog.setResponse(JSONUtil.toJsonStr(responseDTO));
        apiLogDao.save(apiLog);
        return responseDTO;

    }

    public ResultContent<XiaoJuStore> queryStoreDetail(String storeId) {
        XiaoJuStore byStoreId = xiaoJuStoreDao.findByStoreId(storeId);
        return ResultContent.build(ResultState.Success, byStoreId);
    }

    public ResultContent<XiaoJuStore> queryStoreDetail2(String storeId) {
        AuthDetails currentUser = authHelper.getCurrentUser();
        QueryStoreDetailRequest queryStoreDetailRequest = new QueryStoreDetailRequest();

        queryStoreDetailRequest.setOutUserId(currentUser.getUserId());
        queryStoreDetailRequest.setMobile(currentUser.getPhone());
        queryStoreDetailRequest.setStoreId(storeId);
        queryStoreDetailRequest.setOpenChannel(1);

        QueryClient queryClient = QueryClientFactory.create(oilConfig);
        ApiLog apiLog = new ApiLog();
        apiLog.setService("queryStoreDetail");
        apiLog.setRequest(JSONUtil.toJsonStr(queryStoreDetailRequest));
        apiLog.setSystem("xiaoju");
        try {
            QueryStoreDetailResponse queryStoreDetailResponse = queryClient.api().queryStoreDetail(queryStoreDetailRequest);

            XiaoJuStore byStoreId = xiaoJuStoreDao.findByStoreId(storeId);
            List<StoreDetailItemInfo> itemInfoList = queryStoreDetailResponse.getItemInfoList();
            if (ObjectUtil.isEmpty(byStoreId)) {
                XiaoJuStore xiaoJuStore = new XiaoJuStore();
                BeanUtils.copyProperties(queryStoreDetailResponse, xiaoJuStore);
                xiaoJuStore.setLogo(queryStoreDetailResponse.getStoreLogo());
                xiaoJuStore.setLocation(new double[]{queryStoreDetailResponse.getLon(), queryStoreDetailResponse.getLat()});
                xiaoJuStore.setPicList(queryStoreDetailResponse.getStorePicList());


                List<ItemPriceInfoForCallback> itemInfoList1 = new ArrayList<>();
                for (StoreDetailItemInfo storeDetailItemInfo : itemInfoList) {
                    ItemPriceInfoForCallback itemPriceInfoForCallback = new ItemPriceInfoForCallback();
                    BeanUtils.copyProperties(storeDetailItemInfo, itemPriceInfoForCallback);
                    itemPriceInfoForCallback.setGunNoList(storeDetailItemInfo.getGunNos());
                    itemInfoList1.add(itemPriceInfoForCallback);
                }
                xiaoJuStore.setItemInfoList(itemInfoList1);
                xiaoJuStoreDao.save(xiaoJuStore);
            } else {

                BeanUtils.copyProperties(queryStoreDetailResponse, byStoreId, "id", "updateTime");
                byStoreId.setLocation(new double[]{queryStoreDetailResponse.getLon(), queryStoreDetailResponse.getLat()});
                byStoreId.setLogo(queryStoreDetailResponse.getStoreLogo());
                byStoreId.setPicList(queryStoreDetailResponse.getStorePicList());
                List<ItemPriceInfoForCallback> itemInfoList1 = new ArrayList<>();
                for (StoreDetailItemInfo storeDetailItemInfo : itemInfoList) {
                    ItemPriceInfoForCallback itemPriceInfoForCallback = new ItemPriceInfoForCallback();
                    BeanUtils.copyProperties(storeDetailItemInfo, itemPriceInfoForCallback);
                    itemPriceInfoForCallback.setGunNoList(storeDetailItemInfo.getGunNos());
                    itemInfoList1.add(itemPriceInfoForCallback);
                }
                byStoreId.setItemInfoList(itemInfoList1);
                xiaoJuStoreDao.save(byStoreId);


            }

            apiLog.setResponse(JSONUtil.toJsonStr(queryStoreDetailResponse));
            apiLogDao.save(apiLog);


            return ResultContent.buildContent(byStoreId);
        } catch (Exception e) {

            e.printStackTrace();
            apiLog.setResponse(e.getCause().getCause().getMessage());
            apiLogDao.save(apiLog);
            return ResultContent.build(ResultState.Fail, e.getCause().getCause().getMessage().split("详细")[0]);
        }

    }

    public ResultContent<List<StorePriceInfo>> queryStorePrice(QueryApiStorePriceRequest queryApiStorePriceRequest) {
        com.xiaoju.open.oil.interfaces.request.QueryApiStorePriceRequest queryApiStorePriceRequest1 = new com.xiaoju.open.oil.interfaces.request.QueryApiStorePriceRequest();
        queryApiStorePriceRequest1.setOutUserId(queryApiStorePriceRequest.getOutUserId());
        queryApiStorePriceRequest1.setStoreIds(queryApiStorePriceRequest.getStoreIds());
        queryApiStorePriceRequest1.setOpenChannel(1);


        QueryClient queryClient = QueryClientFactory.create(oilConfig);
        ApiLog apiLog = new ApiLog();
        apiLog.setService("queryStorePrice");
        apiLog.setRequest(JSONUtil.toJsonStr(queryApiStorePriceRequest));
        apiLog.setSystem("xiaoju");
        try {
            List<QueryApiStorePriceResponse> list1 = queryClient.api().queryStorePrice(queryApiStorePriceRequest1);
            apiLog.setResponse(JSONUtil.toJsonStr(list1));
            apiLogDao.save(apiLog);
            return ResultContent.buildContent(list1);
        } catch (Exception e) {
            e.printStackTrace();
            apiLog.setResponse(e.getCause().getCause().getMessage());
            apiLogDao.save(apiLog);
            return ResultContent.build(ResultState.Fail, e.getCause().getCause().getMessage().split("详细")[0]);
        }
    }

    @Override
    public ResultContent<Map<String, String>> storeInfo(QueryApiStorePriceRequest queryApiStorePriceRequest) {
        HashMap<String, String> stringStringHashMap = new HashMap<>();
        ResultContent<List<StorePriceInfo>> listResultContent = queryStorePrice(queryApiStorePriceRequest);
        for (StorePriceInfo storePriceInfo : listResultContent.getContent()) {
            XiaoJuStore byStoreId = xiaoJuStoreDao.findByStoreId(storePriceInfo.getStoreId());
            JSONObject entries = JSONUtil.parseObj(byStoreId);
            List<ItemPriceInfo> itemInfoList = storePriceInfo.getItemInfoList();
            entries.put("itemInfoList", itemInfoList);

            stringStringHashMap.put(storePriceInfo.getStoreId(), JSONUtil.toJsonStr(entries));

        }


        return ResultContent.buildContent(stringStringHashMap);
    }


    public ResultContent<List<XiaoJuStoreModel>> nearbyStore(NearbyModel nearbyModel) {

        List<XiaoJuStoreModel> nearbyTargets = xiaoJuStoreDao.findNearbyTargets(nearbyModel);
        return ResultContent.buildContent(nearbyTargets);
    }


    // 价格计算
    public ResultContent<QueryCalPriceResponse> queryCalPrice(QueryCalPriceModel queryCalPriceModel) {

        String userId = authHelper.getCurrentUser().getUserId();
        QueryCalPriceRequest queryCalPriceRequest = new QueryCalPriceRequest();
        queryCalPriceRequest.setStoreId(queryCalPriceModel.getStoreId());
        queryCalPriceRequest.setOpenChannel(1);
        queryCalPriceRequest.setOutUserId(userId);
        queryCalPriceRequest.setItemName(queryCalPriceModel.getItemName());
        queryCalPriceRequest.setAmount(queryCalPriceModel.getAmount());

        queryCalPriceRequest.setPromotionInfo(queryCalPriceModel.getAllowanceinfo());

        QueryClient queryClient = QueryClientFactory.create(oilConfig);
        ApiLog apiLog = new ApiLog();
        apiLog.setService("queryCalPrice");
        apiLog.setRequest(JSONUtil.toJsonStr(queryCalPriceRequest));
        apiLog.setSystem("xiaoju");
        try {
            QueryCalPriceResponse queryCalPriceResponse = queryClient.api().queryCalPrice(queryCalPriceRequest);
            apiLog.setResponse(JSONUtil.toJsonStr(queryCalPriceResponse));
            apiLogDao.save(apiLog);
            return ResultContent.buildContent(queryCalPriceResponse);
        } catch (Exception e) {
            e.printStackTrace();
            apiLog.setResponse(e.getCause().getCause().getMessage());
            apiLogDao.save(apiLog);
            return ResultContent.build(ResultState.Fail, e.getCause().getCause().getMessage().split("详细")[0]);
        }

    }


    // 批量价格计算
    public ResultContent<QueryCalBatchPriceResponse> queryCalPrices(QueryCalPricesModel queryCalPricesModel) {

        String userId = authHelper.getCurrentUser().getUserId();
        QueryCalBatchPriceRequest queryCalPriceRequest = new QueryCalBatchPriceRequest();
        queryCalPriceRequest.setStoreId(queryCalPricesModel.getStoreId());
        queryCalPriceRequest.setOpenChannel(1);
        queryCalPriceRequest.setOutUserId(userId);

        queryCalPriceRequest.setItemList(queryCalPricesModel.getItemList());

        QueryClient queryClient = QueryClientFactory.create(oilConfig);
        ApiLog apiLog = new ApiLog();
        apiLog.setService("queryCalPrices");
        apiLog.setRequest(JSONUtil.toJsonStr(queryCalPriceRequest));
        apiLog.setSystem("xiaoju");
        try {
            QueryCalBatchPriceResponse queryCalBatchPriceResponse = queryClient.api().queryCalPrices(queryCalPriceRequest);
            apiLog.setResponse(JSONUtil.toJsonStr(queryCalBatchPriceResponse));
            apiLogDao.save(apiLog);
            return ResultContent.buildContent(queryCalBatchPriceResponse);
        } catch (Exception e) {
            apiLog.setResponse(e.getCause().getCause().getMessage());
            apiLogDao.save(apiLog);
            return ResultContent.build(ResultState.Fail, e.getCause().getCause().getMessage().split("详细")[0]);
        }
    }


    // 创建订单
    public ResultContent<QueryNewOrderResponse> queryNewOrder(XiaoJuQueryNewOrderModel xiaoJuQueryNewOrderModel) {

        String orderNo = String.valueOf(snowflake.nextId());

        AuthDetails currentUser = authHelper.getCurrentUser();
        String phone = currentUser.getPhone();
        String userId = currentUser.getUserId();

        XiaoJuStore byStoreId = xiaoJuStoreDao.findByStoreId(xiaoJuQueryNewOrderModel.getStoreId());

        QueryNewOrderRequest queryNewOrderRequest = new QueryNewOrderRequest();
        queryNewOrderRequest.setOutUserId(userId);
        queryNewOrderRequest.setMobile(phone);
        queryNewOrderRequest.setLat(byStoreId.getLat());
        queryNewOrderRequest.setLon(byStoreId.getLon());
        queryNewOrderRequest.setStoreId(byStoreId.getStoreId());
        queryNewOrderRequest.setItemId(xiaoJuQueryNewOrderModel.getItemId());
        queryNewOrderRequest.setGunNo(xiaoJuQueryNewOrderModel.getGunNo());
        queryNewOrderRequest.setOriginalAmount(xiaoJuQueryNewOrderModel.getOriginalAmount());
        queryNewOrderRequest.setPaymentAmount(xiaoJuQueryNewOrderModel.getPaymentAmount());
        queryNewOrderRequest.setServiceFee(xiaoJuQueryNewOrderModel.getServiceFee());
        queryNewOrderRequest.setLitre(xiaoJuQueryNewOrderModel.getLitre());
        queryNewOrderRequest.setVipPrice(xiaoJuQueryNewOrderModel.getVipPrice());
        queryNewOrderRequest.setStorePrice(xiaoJuQueryNewOrderModel.getStorePrice());
        queryNewOrderRequest.setPromotionInfo(xiaoJuQueryNewOrderModel.getPromotionInfo());
        queryNewOrderRequest.setOutOrderId(orderNo);


        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        ApiLog apiLog = new ApiLog();
        apiLog.setService("queryNewOrder");
        apiLog.setRequest(JSONUtil.toJsonStr(queryNewOrderRequest));
        apiLog.setSystem("xiaoju");
        try {
            QueryNewOrderResponse queryNewOrderResponse = queryClient.api().queryNewOrder(queryNewOrderRequest);
            XiaoJuOrder xiaoJuOrder = new XiaoJuOrder();
            BeanUtils.copyProperties(queryNewOrderResponse, xiaoJuOrder);
            BeanUtils.copyProperties(queryNewOrderRequest, xiaoJuOrder);
            xiaoJuOrderDao.save(xiaoJuOrder);
            apiLog.setResponse(JSONUtil.toJsonStr(queryNewOrderResponse));
            apiLogDao.save(apiLog);

            /*************************************************************************/
            // 平台订单

            CreateOrder2Model createOrder2Model = new CreateOrder2Model();
            createOrder2Model.setShopId(xiaoJuQueryNewOrderModel.getEpId());
            createOrder2Model.setUserId(userId);
            createOrder2Model.setOrderNo(orderNo);

            JSONObject shopInfo = JSONUtil.parseObj(byStoreId);
            shopInfo.put("shopName", byStoreId.getStoreName());

            createOrder2Model.setShopInfo(shopInfo);

            BigDecimal total = BigDecimal.valueOf(xiaoJuQueryNewOrderModel.getOriginalAmount()).divide(BigDecimal.valueOf(100));
            BigDecimal payment = BigDecimal.valueOf(xiaoJuQueryNewOrderModel.getPaymentAmount()).divide(BigDecimal.valueOf(100));
            BigDecimal serviceFee = BigDecimal.valueOf(xiaoJuQueryNewOrderModel.getServiceFee()).divide(BigDecimal.valueOf(100));

            createOrder2Model.setTotalAmount(total);
            createOrder2Model.setPayAmount(payment);
            createOrder2Model.setDiscountAmount(total.subtract(payment));
            createOrder2Model.setAccesserUserId("");

            CreateOrder2Model.Goods goods = new CreateOrder2Model.Goods();
            goods.setGoodsId("");
            goods.setJobFlowMap(JobFlowMap.XiaoJu);
            JSONObject goodsInfo = JSONUtil.parseObj(queryNewOrderRequest);
            goodsInfo.put("goodsName", byStoreId.getStoreName());
            goodsInfo.put("goodsPath", byStoreId.getLogo());
            goodsInfo.put("itemName", xiaoJuQueryNewOrderModel.getItemName());
            goods.setGoodsInfo(goodsInfo);
            goods.setPayAmount(payment);
            goods.setTransferType(TransferType.RATIO);
            CreateOrder2Model.Owner shop = new CreateOrder2Model.Owner();
            shop.setOwner(TransferOwner.BUY_SHOP);
            shop.setShopId(xiaoJuQueryNewOrderModel.getEpId());
            shop.setValue(BigDecimal.valueOf(100));
            goods.setTransferRrule(List.of(shop));
            createOrder2Model.setGoodsList(List.of(goods));
            createOrder2Model.setChannel(xiaoJuQueryNewOrderModel.getChannel());

            ResultContent<CreatOrderResultModel> creat = orderService2.creat(createOrder2Model);
            if (!creat.getState().equals(ResultState.Success)) {
                return ResultContent.build(ResultState.Fail, "创建订单失败");
            }
            log.info("创建订单结果：{}", JSONUtil.toJsonStr(creat.getContent()));
            // 平台订单结束
            /*************************************************************************/


            UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();
            updateGoodsModel.setExtend(JSONUtil.toJsonStr(queryNewOrderResponse));
            updateOrder(queryNewOrderResponse.getOutOrderId(), updateGoodsModel);
            return ResultContent.buildContent(queryNewOrderResponse);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultContent.build(ResultState.Fail, e.getCause().getCause().getMessage().split("详细")[0]);
//            return ResultContent.build(ResultState.Fail, e.getMessage());

        }


    }


    // 取消订单
    public ResultContent cancelOrder(QueryNewOrderResponse queryNewOrderResponse) {
        MiniCancelOrderStatusRequest cancelOrderStatusRequest = new MiniCancelOrderStatusRequest();
        cancelOrderStatusRequest.setOutOrderId(queryNewOrderResponse.getOutOrderId());
        cancelOrderStatusRequest.setXjOrderId(queryNewOrderResponse.getXjOrderId());
        QueryClient queryClient = QueryClientFactory.create(oilConfig);
        ApiLog apiLog = new ApiLog();
        apiLog.setService("cancelOrder");
        apiLog.setSystem("xiaoju");
        apiLog.setRequest(JSONUtil.toJsonStr(cancelOrderStatusRequest));
        try {
            queryClient.apiMini().cancelOrder(cancelOrderStatusRequest);
            apiLog.setResponse(null);
            apiLogDao.save(apiLog);
            UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();
            updateGoodsModel.setGoodsState(OrderType.CLOSE);
            updateOrder(queryNewOrderResponse.getOutOrderId(), updateGoodsModel);

        } catch (Exception e) {
            e.printStackTrace();
            apiLog.setResponse(e.getCause().getCause().getMessage());
            apiLogDao.save(apiLog);
            ResultContent resultContent = ResultContent.build(ResultState.Fail, e.getCause().getCause().getMessage().split("详细")[0]);
            return resultContent;
        }

        return ResultContent.build(ResultState.Success);
    }


    // 同步订单状态
    public void syncOrderStatus(SynOrderStatusRequest synOrderStatusRequest) {

        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        queryClient.api().syncOrderStatus(synOrderStatusRequest);

    }


    // 查询订单列表
    public QueryApiOrderListResponse queryOrderList(QueryApiOrderListRequest queryApiOrderListRequest) {
        String userId = authHelper.getCurrentUser().getUserId();

        queryApiOrderListRequest.setMobile(authHelper.getCurrentUser().getPhone());
        queryApiOrderListRequest.setOutUserId(userId);

        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        QueryApiOrderListResponse queryApiOrderListResponse = queryClient.api().queryOrderList(queryApiOrderListRequest);

        return queryApiOrderListResponse;


    }

    // 查询订单列表
    public QueryApiOrderListResponse queryOrderList2(QueryApiOrderListRequest queryApiOrderListRequest) {
        String userId = authHelper.getCurrentUser().getUserId();

//        xiaoJuOrderDao.findByOutOrderId();

        queryApiOrderListRequest.setMobile(authHelper.getCurrentUser().getPhone());
        queryApiOrderListRequest.setOutUserId(userId);

        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        QueryApiOrderListResponse queryApiOrderListResponse = queryClient.api().queryOrderList(queryApiOrderListRequest);

        return queryApiOrderListResponse;


    }


    // 下单前查询最优可用券
    public ResultContent<List<AllowancePromotionInfo>> queryOrderPromotionList(XiaoJuQueryOrderPromotionListModel xiaoJuQueryOrderPromotionListModel) {
        String userId = authHelper.getCurrentUser().getUserId();
        QueryOrderPromotionListRequest request = new QueryOrderPromotionListRequest();
        request.setOutUserId(userId);
        request.setStoreId(xiaoJuQueryOrderPromotionListModel.getStoreId());
        request.setAllowanceType(2);
        request.setMobile(authHelper.getCurrentUser().getPhone());
        request.setOrderAmount(xiaoJuQueryOrderPromotionListModel.getOrderAmount());

        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        ApiLog apiLog = new ApiLog();
        apiLog.setService("queryOrderPromotionList");
        apiLog.setRequest(JSONUtil.toJsonStr(request));
        apiLog.setSystem("xiaoju");
        try {
            List<AllowancePromotionInfo> response = queryClient.promotion().queryOrderPromotionList(request);
            apiLog.setResponse(JSONUtil.toJsonStr(response));
            apiLogDao.save(apiLog);
            return ResultContent.build(ResultState.Success, response == null ? List.of() : response);
        } catch (Exception e) {
            e.printStackTrace();
            apiLog.setResponse(e.getCause().getCause().getMessage());
            apiLogDao.save(apiLog);
            return ResultContent.build(ResultState.Fail, e.getCause().getCause().getMessage().split("详细")[0]);
        }

    }


    // 查询多个门店可用券
    public ResultContent<List<AllowancePromotionInfo>> queryStorePromotionList(List<String> storeIdList) {
        AuthDetails currentUser = authHelper.getCurrentUser();
        QueryStorePromotionListRequest request = new QueryStorePromotionListRequest();
        request.setMobile(currentUser.getPhone());
        request.setAllowanceType(2);
        request.setOutUserId(currentUser.getUserId());
        request.setStoreIdList(storeIdList);

        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        ApiLog apiLog = new ApiLog();
        apiLog.setService("queryStorePromotionList");
        apiLog.setRequest(JSONUtil.toJsonStr(request));
        apiLog.setSystem("xiaoju");
        try {
            List<AllowancePromotionInfo> response = queryClient.promotion().queryStorePromotionList(request);
            apiLog.setResponse(JSONUtil.toJsonStr(response));
            apiLogDao.save(apiLog);
            return ResultContent.build(ResultState.Success, response);
        } catch (Exception e) {
            apiLog.setResponse(e.getCause().getCause().getMessage());
            apiLogDao.save(apiLog);
            return ResultContent.build(ResultState.Fail, e.getCause().getCause().getMessage().split("详细")[0]);
        }

    }

    // 查询用户所有券列表
    public ResultContent<com.zswl.cloud.springBatch.client.model.xiaoju.QueryUserPromotionListResponse> queryUserPromotionList(XiaoJuQueryUserPromotionListModel xiaoJuQueryUserPromotionListModel) {

        QueryUserPromotionListRequest request = new QueryUserPromotionListRequest();
        request.setMobile(xiaoJuQueryUserPromotionListModel.getMobile());
        request.setAllowanceType(2);
        request.setOutUserId(xiaoJuQueryUserPromotionListModel.getOutUserId());
        request.setStatus(xiaoJuQueryUserPromotionListModel.getStatus());
        request.setPageIndex(xiaoJuQueryUserPromotionListModel.getPageIndex());
        request.setPageSize(xiaoJuQueryUserPromotionListModel.getPageSize());

        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        ApiLog apiLog = new ApiLog();
        apiLog.setService("queryUserPromotionList");
        apiLog.setRequest(JSONUtil.toJsonStr(request));
        apiLog.setSystem("xiaoju");
        try {
            QueryUserPromotionListResponse response = queryClient.promotion().queryUserPromotionList(request);
            apiLog.setResponse(JSONUtil.toJsonStr(response));
            apiLogDao.save(apiLog);
            return ResultContent.build(ResultState.Success, response);
        } catch (Exception e) {

            e.printStackTrace();
            apiLog.setResponse(e.getCause().getCause().getMessage());
            apiLogDao.save(apiLog);
            return ResultContent.build(ResultState.Fail, e.getCause().getCause().getMessage().split("详细")[0]);
        }
    }

    public ResultContent<List<com.zswl.cloud.springBatch.client.model.xiaoju.GenPromotionInfo>> getPromotion(com.zswl.cloud.springBatch.client.model.xiaoju.QueryGetPromotionRequest queryGetPromotionRequest) {
        QueryClient queryClient = QueryClientFactory.create(oilConfig);
        ApiLog apiLog = new ApiLog();
        apiLog.setService("queryUserPromotionList");
        apiLog.setRequest(JSONUtil.toJsonStr(queryGetPromotionRequest));
        apiLog.setSystem("xiaoju");
        QueryGetPromotionRequest queryGetPromotionRequest1 = new QueryGetPromotionRequest();
        BeanUtils.copyProperties(queryGetPromotionRequest, queryGetPromotionRequest1);
        try {
            List<GenPromotionInfo> response = queryClient.promotion().getPromotion(queryGetPromotionRequest1);
            XiaoJuActivityReceiver xiaoJuActivityReceiver = new XiaoJuActivityReceiver();
            xiaoJuActivityReceiver.setActivityId(queryGetPromotionRequest.getActivityId());
            xiaoJuActivityReceiver.setUserId(queryGetPromotionRequest.getOutUserId());
            xiaoJuActivityReceiver.setTradeNo(queryGetPromotionRequest.getTradeNo());
            xiaoJuActivityReceiverDao.save(xiaoJuActivityReceiver);
            apiLog.setResponse(JSONUtil.toJsonStr(response));
            apiLogDao.save(apiLog);
            return ResultContent.buildContent(response);
        } catch (Exception e) {
            e.printStackTrace();
            apiLog.setResponse(e.getCause().getCause().getMessage());
            apiLogDao.save(apiLog);
            return ResultContent.build(ResultState.Fail, e.getCause().getCause().getMessage().split("详细")[0]);

        }

    }

    // 券发放
    public ResultContent<List<GenPromotionInfo>> getPromotion(String activityId) {
        AuthDetails currentUser = authHelper.getCurrentUser();
//        XiaoJuActivity byActivityId = xiaoJuActivityDao.findByActivityId(activityId);
//        if (byActivityId == null) {
//            return ResultContent.build(ResultState.Fail, "活动不存在");
//        }
//
//        AtomicBoolean grant = new AtomicBoolean(false);
//        List<String> planningId = byActivityId.getPlanningId();
//
//        planningId.forEach(it -> {
//            ResultContent<List<VipUserModel>> listResultContent = vipUserService.userInfo(currentUser.getPhone());
//            List<VipUserModel> content = listResultContent.getContent();
//            List<String> collect = content.stream().map(vipUserModel -> vipUserModel.getPlanningId()).collect(Collectors.toList());
//            for (String s : planningId) {
//                grant.set(collect.remove(s));
//            }
//        });
//
//        if (!grant.get()) {
//            return ResultContent.build(ResultState.Fail, "当前会员不能领取");
//        }
//        DateTime dateTime = DateUtil.beginOfMonth(new Date());
//        List<XiaoJuActivityReceiver> xiaoJuActivityReceivers = xiaoJuActivityReceiverDao.findByUserIdAndCreateTimeAfter(currentUser.getUserId(), dateTime.getTime());
//        if (xiaoJuActivityReceivers.size() >= 3) {
//            return ResultContent.build(ResultState.Fail, "当月已经领取3次");
//
//        }
//
//        XiaoJuQueryUserPromotionListModel xiaoJuQueryUserPromotionListModel = new XiaoJuQueryUserPromotionListModel();
//        xiaoJuQueryUserPromotionListModel.setPageIndex(1);
//        xiaoJuQueryUserPromotionListModel.setPageSize(20);
//        xiaoJuQueryUserPromotionListModel.setStatus(5);
//        xiaoJuQueryUserPromotionListModel.setMobile(currentUser.getPhone());
//        xiaoJuQueryUserPromotionListModel.setOutUserId(currentUser.getUserId());
//
//        ResultContent<com.zswl.cloud.springBatch.client.model.xiaoju.QueryUserPromotionListResponse> queryUserPromotionListResponseResultContent = queryUserPromotionList(xiaoJuQueryUserPromotionListModel);
//        com.zswl.cloud.springBatch.client.model.xiaoju.QueryUserPromotionListResponse queryUserPromotionListResponse = queryUserPromotionListResponseResultContent.getContent();
//
//        if (queryUserPromotionListResponse.getTotalSize() != 0) {
//            return ResultContent.build(ResultState.Fail, "有未消费的优惠券，请先使用");
//        }

        String tradeNo = snowflake.nextIdStr();

        QueryGetPromotionRequest queryGetPromotionRequest = new QueryGetPromotionRequest();
        queryGetPromotionRequest.setActivityId(activityId);
        queryGetPromotionRequest.setOutUserId(currentUser.getUserId());
        queryGetPromotionRequest.setMobile(currentUser.getPhone());
        queryGetPromotionRequest.setTradeNo(tradeNo);


        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        ApiLog apiLog = new ApiLog();
        apiLog.setService("queryUserPromotionList");
        apiLog.setRequest(JSONUtil.toJsonStr(queryGetPromotionRequest));
        apiLog.setSystem("xiaoju");
        try {
            List<GenPromotionInfo> response = queryClient.promotion().getPromotion(queryGetPromotionRequest);
            XiaoJuActivityReceiver xiaoJuActivityReceiver = new XiaoJuActivityReceiver();
            xiaoJuActivityReceiver.setActivityId(activityId);
            xiaoJuActivityReceiver.setUserId(currentUser.getUserId());
            xiaoJuActivityReceiver.setTradeNo(tradeNo);
            xiaoJuActivityReceiverDao.save(xiaoJuActivityReceiver);
            apiLog.setResponse(JSONUtil.toJsonStr(response));
            apiLogDao.save(apiLog);
            return ResultContent.buildContent(response);
        } catch (Exception e) {
            e.printStackTrace();
            apiLog.setResponse(e.getCause().getCause().getMessage());
            apiLogDao.save(apiLog);
            return ResultContent.build(ResultState.Fail, e.getCause().getCause().getMessage().split("详细")[0]);

        }
    }


    public ResultContent<XiaoJuActivity> addActivity(ActivityModel addActivityModel) {
        if (ObjectUtil.isEmpty(addActivityModel.getId())) {
            XiaoJuActivity xiaoJuActivity = new XiaoJuActivity();
            BeanUtils.copyProperties(addActivityModel, xiaoJuActivity);
            return ResultContent.build(ResultState.Success, xiaoJuActivityDao.save(xiaoJuActivity));
        }
        Optional<XiaoJuActivity> byId = xiaoJuActivityDao.findById(addActivityModel.getId());
        if (byId.isPresent()) {
            XiaoJuActivity xiaoJuActivity = byId.get();
            BeanUtils.copyProperties(addActivityModel, xiaoJuActivity);
            return ResultContent.build(ResultState.Success, xiaoJuActivityDao.save(xiaoJuActivity));
        }
        return ResultContent.build(ResultState.Fail, "数据不存在");
    }


    private void updateOrder(String orderNo, UpdateGoodsModel updateGoodsModel) {

        ResultContent<List<GoodsResultModel>> listResultContent = orderService2.goodsDetail(orderNo);

        for (GoodsResultModel goodsResultModel : listResultContent.getContent()) {
            updateGoodsModel.setId(goodsResultModel.getId());
            orderService2.updateGoods(updateGoodsModel);
        }


    }
}
